"""This is where you should include a module docstring to explain this file's functionality.

There are various formats SEE: https://canadiancoding.ca/posts/post/python/docstrings/
    For this example I will use numpystyle docstrings: https://numpydoc.readthedocs.io/en/latest/format.html

Variables
---------
This is where you mention any module-global variables.

Functions
---------
This is where you can specify any functions and what they return.

Notes
-----
Any other useful information.

References
----------
If you are implementing complicated functionality that has associated references (papers, videos, presentations etc.)
    leave links to them here.

Examples
--------
Any useful examples of basic usage of this module, make sure to enclose code in 3 backtics, this is
    interpreted by most modern IDE's as needing syntax highlighting which is quite useful. Here is an
    example:
    ```
    import this
    ```
"""

if __name__ == "__main__": # Code inside this statement will only run if the file is explicitly called and not just imported.
    pass