"""
You shouldn't need to modify this file, but if you are making submodules (nested folders + files) you
    will need to include a __init__.py file that has relative import statements.

Example
-------
If you have a submodule folder called /foo, with a module inside called bar.py you will need to include
    a __init__.py file in /foo with the following import statement:
        ```
        from .bar import *
        ```
    If you don't do this python won't find the contents of the files inside the submodule folder.

"""